@@ -13,15 +13,16 @@ import json
 # local imports
 import tmrl.config.config_constants as cfg
 import tmrl.config.config_objects as cfg_obj
-from tmrl import run_tm, run_wandb_tm, record_reward_dist, check_env_tm20lidar
-from tmrl.envs import UntouchedGymEnv
-from tmrl.networking import RolloutWorker, Server, TrainerInterface
+from tmrl.tools.record import record_reward_dist
+from tmrl.tools.check_environment import check_env_tm20lidar
+from tmrl.envs import GenericGymEnv
+from tmrl.networking import Server, Trainer, RolloutWorker
 from tmrl.util import partial
 
 
 def main(args):
     if args.server:
-        Server(samples_per_server_packet=1000 if not cfg.CRC_DEBUG else cfg.CRC_DEBUG_SAMPLES)
+        Server(min_samples_per_server_packet=1000 if not cfg.CRC_DEBUG else cfg.CRC_DEBUG_SAMPLES)
         while True:
             time.sleep(1.0)
     elif args.worker or args.test or args.benchmark:
@@ -29,12 +30,12 @@ def main(args):
         config_modifiers = args.config
         for k, v in config_modifiers.items():
             config[k] = v
-        rw = RolloutWorker(env_cls=partial(UntouchedGymEnv, id="rtgym:real-time-gym-v0", gym_kwargs={"config": config}),
+        rw = RolloutWorker(env_cls=partial(GenericGymEnv, id="real-time-gym-v0", gym_kwargs={"config": config}),
                            actor_module_cls=partial(cfg_obj.POLICY, act_buf_len=cfg.ACT_BUF_LEN),
-                           get_local_buffer_sample=cfg_obj.SAMPLE_COMPRESSOR,
+                           sample_compressor=cfg_obj.SAMPLE_COMPRESSOR,
                            device='cuda' if cfg.PRAGMA_CUDA_INFERENCE else 'cpu',
                            server_ip=cfg.SERVER_IP_FOR_WORKER,
-                           samples_per_worker_packet=1000 if not cfg.CRC_DEBUG else cfg.CRC_DEBUG_SAMPLES,
+                           min_samples_per_worker_packet=1000 if not cfg.CRC_DEBUG else cfg.CRC_DEBUG_SAMPLES,
                            max_samples_per_episode=cfg.RW_MAX_SAMPLES_PER_EPISODE,
                            model_path=cfg.MODEL_PATH_WORKER,
                            obs_preprocessor=cfg_obj.OBS_PREPROCESSOR,
@@ -43,12 +44,23 @@ def main(args):
         if args.worker:
             rw.run()
         elif args.benchmark:
-            rw.run_env_benchmark(nb_steps=1000, deterministic=False)
+            rw.run_env_benchmark(nb_steps=1000, test=False)
         else:
             rw.run_episodes(10000)
-
     elif args.trainer:
-        main_train(args)
+        trainer = Trainer(training_cls=cfg_obj.TRAINER,
+                          server_ip=cfg.SERVER_IP_FOR_TRAINER,
+                          model_path=cfg.MODEL_PATH_TRAINER,
+                          checkpoint_path=cfg.CHECKPOINT_PATH,
+                          dump_run_instance_fn=cfg_obj.DUMP_RUN_INSTANCE_FN,
+                          load_run_instance_fn=cfg_obj.LOAD_RUN_INSTANCE_FN)
+        logging.info(f"--- NOW RUNNING: SAC trackmania ---")
+        if not args.no_wandb:
+            trainer.run_with_wandb(entity=cfg.WANDB_ENTITY,
+                                   project=cfg.WANDB_PROJECT,
+                                   run_id=cfg.WANDB_RUN_ID)
+        else:
+            trainer.run()
     elif args.record_reward:
         assert cfg.PRAGMA_TM2020_TMNF, "Not supported for this environment."
         record_reward_dist(path_reward=cfg.REWARD_PATH)
@@ -59,25 +71,6 @@ def main(args):
         raise ArgumentTypeError('Enter a valid argument')
 
 
-def main_train(args):
-
-    train_cls = cfg_obj.TRAINER
-
-    logging.info(f"--- NOW RUNNING: SAC/DCAC trackmania ---")
-    interface = TrainerInterface(server_ip=cfg.SERVER_IP_FOR_TRAINER, model_path=cfg.MODEL_PATH_TRAINER)
-    if not args.no_wandb:
-        run_wandb_tm(entity=cfg.WANDB_ENTITY,
-                     project=cfg.WANDB_PROJECT,
-                     run_id=cfg.WANDB_RUN_ID,
-                     interface=interface,
-                     run_cls=train_cls,
-                     checkpoint_path=cfg.CHECKPOINT_PATH,
-                     dump_run_instance_fn=cfg_obj.DUMP_RUN_INSTANCE_FN,
-                     load_run_instance_fn=cfg_obj.LOAD_RUN_INSTANCE_FN)
-    else:
-        run_tm(interface=interface, run_cls=train_cls, checkpoint_path=cfg.CHECKPOINT_PATH, dump_run_instance_fn=cfg_obj.DUMP_RUN_INSTANCE_FN, load_run_instance_fn=cfg_obj.LOAD_RUN_INSTANCE_FN)
-
-
 if __name__ == "__main__":
     parser = ArgumentParser()
     parser.add_argument('--server', action='store_true', help='launches the server')
